﻿namespace Phoenix.Main.Configuration
{
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Linq;
    using System.Text;

    using Phoenix.Main.Properties;

    public sealed class GeneralConfiguration : IConfigurationMemento
    {
        #region Constructors

        public GeneralConfiguration()
        {
            this.SaveState();
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the generic format for dates.
        /// </summary>
        /// <value>The date format.</value>
        [Category("General")]
        [DisplayName("Generic format for dates.")]
        public string DateFormat
        {
            get { return Settings.Default.General_DateFormat; }
            set { Settings.Default.General_DateFormat = value; }
        }

        /// <summary>
        /// Gets or sets the maximum height accepted before a warning.
        /// </summary>
        /// <value>The max height.</value>
        public ushort MaxHeight
        {
            get { return Settings.Default.General_MaxHeight; }
            set { Settings.Default.General_MaxHeight = value; }
        }

        /// <summary>
        /// Gets or sets the max weight accepted before a warning.
        /// </summary>
        /// <value>The max weight.</value>
        public double MaxWeight
        {
            get { return Settings.Default.General_MaxWeight; }
            set { Settings.Default.General_MaxWeight = value; }
        }

        /// <summary>
        /// Gets or sets the mobile number display pattern.
        /// </summary>
        /// <value>The mobile number display pattern.</value>
        [Category("General")]
        [DisplayName("Mobile number display pattern.")]
        public string MobileNumberDisplayPattern
        {
            get { return Settings.Default.General_MobileNumberDisplayPattern; }
            set { Settings.Default.General_MobileNumberDisplayPattern = value; }
        }

        /// <summary>
        /// Gets or sets the phone number display pattern.
        /// </summary>
        /// <value>The phone number display pattern.</value>
        [Category("General")]
        [DisplayName("Phone number display pattern.")]
        public string PhoneNumberDisplayPattern
        {
            get { return Settings.Default.General_PhoneNumberDisplayPattern; }
            set { Settings.Default.General_PhoneNumberDisplayPattern = value; }
        }

        /// <summary>
        /// Gets or sets the maximum size for pictures before warn the user.
        /// </summary>
        /// <value>The picture size to warn.</value>
        [Category("General")]
        [DisplayName("maximum size for pictures.")]
        public int PictureSizeToWarn
        {
            get { return Settings.Default.General_PictureSizeToWarn; }
            set { Settings.Default.General_PictureSizeToWarn = value; }
        }

        internal Memento State
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Commits the changes done in the config file.
        /// </summary>
        public void CommitChanges()
        {
            Settings.Default.Save();
        }

        /// <summary>
        /// Rollbacks this instance to the previous saved state.
        /// </summary>
        public void Rollback()
        {
            this.DateFormat = this.State.DateFormat;
            this.PictureSizeToWarn = this.State.PictureSizeToWarn;
        }

        /// <summary>
        /// Saves the state of this instance.
        /// </summary>
        public void SaveState()
        {
            Memento state = new Memento();
            state.PictureSizeToWarn = this.PictureSizeToWarn;
            state.DateFormat = this.DateFormat;
            this.State = state;
        }

        #endregion Methods

        #region Nested Types

        internal class Memento
        {
            #region Properties

            /// <summary>
            /// Gets or sets the general_ date format.
            /// </summary>
            /// <value>The general_ date format.</value>
            public string DateFormat
            {
                get;
                set;
            }

            /// <summary>
            /// Gets or sets the general_ picture size to warn.
            /// </summary>
            /// <value>The general_ picture size to warn.</value>
            public int PictureSizeToWarn
            {
                get;
                set;
            }

            #endregion Properties
        }

        #endregion Nested Types
    }
}