﻿namespace Phoenix.Model.Administration
{
    using System;
    using System.Linq;
    using System.Threading;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Presenter.Interfaces;

    /// <summary>
    /// Presenter for the administration
    /// </summary>
    public class AdministrationModel
    {
        #region Fields

        private IAdministrationPresenter presenter;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="AdministrationModel"/> class.
        /// </summary>
        /// <param name="presenter">The view.</param>
        public AdministrationModel(IAdministrationPresenter presenter)
        {
            this.presenter = presenter;
            this.presenter.Refreshed += (sender, e) =>
            {
                if (e.TypeChanged == typeof(Reputation))
                    this.RefreshReputation();
                if (e.TypeChanged == typeof(Insurance))
                    this.RefreshInsurance();
                if (e.TypeChanged == typeof(Practice))
                    this.RefreshPractice();
                if (e.TypeChanged == typeof(Doctor))
                    this.RefreshDoctor();
                if (e.TypeChanged == typeof(DoctorType))
                    this.RefreshDoctorType();
                if (e.TypeChanged == typeof(RelationType))
                    this.RefreshRelationType();
                if (e.TypeChanged == typeof(Drug))
                    this.RefreshDrug();
                if (e.TypeChanged == typeof(DrugType))
                    this.RefreshDrugType();
                if (e.TypeChanged == typeof(Pathology))
                    this.RefreshPathology();
                if (e.TypeChanged == typeof(PathologyType))
                    this.RefreshPathologyType();
            };
        }

        #endregion Constructors

        #region Methods

        private void RefreshDoctor()
        {
            Thread thread = new Thread(new ThreadStart((Action)delegate
            {
                var repository = RepositoryFactory.Get<IDoctorRepository>();
                var rows = repository.GetAllRows().OrderBy(e => e.LastName).ToList();
                this.presenter.Doctors = rows;
            }));
            thread.Name = "Refresh doctors.";
            thread.Start();
        }

        private void RefreshDoctorType()
        {
            Thread thread = new Thread(new ThreadStart((Action)delegate
            {
                var repository = RepositoryFactory.Get<IDoctorTypeRepository>();
                var rows = repository.GetAllRows().OrderBy(e => e.Title).ToList();
                this.presenter.DoctorTypes = rows;
            }));
            thread.Name = "Refresh doctor types.";
            thread.Start();
        }

        private void RefreshDrug()
        {
            Thread thread = new Thread(new ThreadStart((Action)delegate
            {
                var repository = RepositoryFactory.Get<IDrugRepository>();
                var rows = repository.GetAllRows().OrderBy(e => e.Title).ToList();
                this.presenter.Drugs = rows;
            }));
            thread.Name = "Refresh drugs.";
            thread.Start();
        }

        private void RefreshDrugType()
        {
            Thread thread = new Thread(new ThreadStart((Action)delegate
            {
                var repository = RepositoryFactory.Get<IDrugTypeRepository>();
                var rows = repository.GetAllRows().OrderBy(e => e.Title).ToList();
                this.presenter.DrugTypes = rows;
            }));
            thread.Name = "Refresh drug types.";
            thread.Start();
        }

        private void RefreshInsurance()
        {
            Thread thread = new Thread(new ThreadStart((Action)delegate
            {
                var repository = RepositoryFactory.Get<IInsuranceRepository>();
                var rows = repository.GetAllRows().OrderBy(e => e.Title).ToList();
                this.presenter.Insurances = rows;
            }));
            thread.Name = "Refresh insurances.";
            thread.Start();
        }

        private void RefreshPathology()
        {
            Thread thread = new Thread(new ThreadStart((Action)delegate
            {
                var repository = RepositoryFactory.Get<IPathologyRepository>();
                var rows = repository.GetAllRows().OrderBy(e => e.Title).ToList();
                this.presenter.Pathologies = rows;
            }));
            thread.Name = "Refresh pathologies.";
            thread.Start();
        }

        private void RefreshPathologyType()
        {
            Thread thread = new Thread(new ThreadStart((Action)delegate
            {
                var repository = RepositoryFactory.Get<IPathologyTypeRepository>();
                var rows = repository.GetAllRows().OrderBy(e => e.Title).ToList();
                this.presenter.PathologyTypes = rows;
            }));
            thread.Name = "Refresh pathology types.";
            thread.Start();
        }

        private void RefreshPractice()
        {
            Thread thread = new Thread(new ThreadStart((Action)delegate
            {
                var repository = RepositoryFactory.Get<IPracticeRepository>();
                var rows = repository.GetAllRows().OrderBy(e => e.Title).ToList();
                this.presenter.Practices = rows;
            }));
            thread.Name = "Refresh practices.";
            thread.Start();
        }

        private void RefreshRelationType()
        {
            Thread thread = new Thread(new ThreadStart((Action)delegate
            {
                var repository = RepositoryFactory.Get<IRelationTypeRepository>();
                var rows = repository.GetAllRows().OrderBy(e => e.Title).ToList();
                this.presenter.RelationTypes = rows;
            }));
            thread.Name = "Refresh relation types.";
            thread.Start();
        }

        private void RefreshReputation()
        {
            Thread thread = new Thread(new ThreadStart((Action)delegate
                {
                    var repository = RepositoryFactory.Get<IReputationRepository>();
                    var rows = repository.GetAllRows().OrderBy(e => e.Title).ToList();
                    this.presenter.Reputations = rows;
                }));
            thread.Name = "Refresh reputations.";
            thread.Start();
        }

        #endregion Methods
    }
}