﻿namespace Phoenix.Presenter.Managers
{
    using System.Collections.Generic;

    using Phoenix.Helpers.Misc;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal.Configuration;
    using Phoenix.Presenter.Manager;
    using Phoenix.Translation;
    using Phoenix.View.Interfaces;

    /// <summary>
    /// Provides features to manage a family link type
    /// </summary>
    public class FamilyLinkTypeManager : Manager<RelationType>
    {
        #region Fields

        private SimpleFamilyLinkTypeManager familyLinkFetcher = new SimpleFamilyLinkTypeManager();
        private IFamilyLinkTypeManager view;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="FamilyLinkTypeManager"/> class.
        /// </summary>
        /// <param name="view">The view.</param>
        public FamilyLinkTypeManager(IFamilyLinkTypeManager view)
            : base(Repositories.Get<IFamilyLinkTypeRepository>())
        {
            this.view = view;
            this.view.Inserted += view_Inserted;
            this.view.Updated += view_Updated;
            this.view.Deleted += view_Deleted;
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Gets all the family link types.
        /// </summary>
        /// <returns></returns>
        public IList<RelationType> GetFamilyLinkTypes()
        {
            return this.familyLinkFetcher.GetFamilyLinkTypes();
        }

        /// <summary>
        /// Validates the data.
        /// </summary>
        /// <returns><c>True</c> if the data have passed the validation;
        /// otherwise <c>False</c></returns>
        public override bool ValidateData()
        {
            bool result = true;
            if (string.IsNullOrEmpty(this.view.ItemToManage.Title))
            {
                this.view.SetError(FamilyLinkTypeFailedOn.EmptyName, "A family link can't be without a name".Translate());
                result = false;
            }
            return result;
        }

        private void view_Deleted(object sender, EventArgs<RelationType> e)
        {
            base.Delete(e.Value);
        }

        private void view_Inserted(object sender, EventArgs<RelationType> e)
        {
            base.Insert(e.Value);
        }

        private void view_Updated(object sender, EventArgs<RelationType> e)
        {
            base.Update(e.Value);
        }

        #endregion Methods
    }
}