﻿namespace Phoenix.Model.Management
{
    using System;

    using Phoenix.Contracts;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Presenter.Interfaces.Input;
    using Phoenix.Translation;

    /// <summary>
    /// Presenter that manage the macros
    /// </summary>
    public class MacroModel : Manager<Macro>
    {
        #region Fields

        private IMacroInputPresenter view;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="MacroModel"/> class.
        /// </summary>
        /// <param name="presenter">The presenter.</param>
        public MacroModel(IMacroInputPresenter presenter)
            : this(presenter, RepositoryFactory.Get<IMacroRepository>())
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="MacroModel"/> class.
        /// </summary>
        /// <param name="presenter">The presenter.</param>
        /// <param name="repository">The repository.</param>
        public MacroModel(IMacroInputPresenter presenter, IRepository<Macro> repository)
            : base(repository)
        {
            this.view = presenter;
            this.view.Inserted += view_Added;
            this.view.Deleted += view_Deleted;
            this.view.Updated += view_Updated;
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Loads the presenter and all the data.
        /// </summary>
        public void Refresh()
        {
            this.RefreshData();
        }

        /// <summary>
        /// Validates the data.
        /// </summary>
        /// <returns><c>True</c> if the data have passed the validation;
        /// otherwise <c>False</c></returns>
        public override bool ValidateData()
        {
            Assert.IsNotNull(this.view.ItemToManage, "ItemToManage");
            this.view.ClearError();

            bool result = true;
            if (string.IsNullOrEmpty(this.view.ItemToManage.Text))
            {
                this.view.Invalidate(MacroFailedOn.EmptyText, "The text of the macro couldn't be empty!".Translate());
                result = false;
            }
            if (string.IsNullOrEmpty(this.view.ItemToManage.Title))
            {
                this.view.Invalidate(MacroFailedOn.EmptyTitle, "The name of the macro couldn't be empty!".Translate());
                result = false;
            }
            return result;
        }

        private void RefreshData()
        {
            this.view.Macros = this.Repository.GetAllRows();
        }

        private void view_Added(object sender, EventArgs e)
        {
            this.Repository.Create(this.view.ItemToManage);
            this.RefreshData();
        }

        private void view_Deleted(object sender, EventArgs e)
        {
            this.Repository.Delete(this.view.ItemToManage);
            this.RefreshData();
        }

        private void view_Updated(object sender, EventArgs e)
        {
            this.Repository.Update(this.view.ItemToManage);
            this.RefreshData();
        }

        #endregion Methods
    }
}