﻿namespace Phoenix.Model.Core.Management
{
    using System.Linq;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Presenter.Interfaces;

    /// <summary>
    /// Manage medical cards
    /// </summary>
    public class MedicalCardModel_BIS
    {
        #region Fields

        private IMacroRepository macroRepository = RepositoryFactory.Get<IMacroRepository>();
        private IMedicalCardTypeRepository mcTypeRepository = RepositoryFactory.Get<IMedicalCardTypeRepository>();
        private IPatientRepository patientRepository = RepositoryFactory.Get<IPatientRepository>();
        private IMedicalCardManagerPresenter presenter;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="MedicalCardModel_BIS"/> class.
        /// </summary>
        /// <param name="presenter">The presenter.</param>
        public MedicalCardModel_BIS(IMedicalCardManagerPresenter presenter)
        {
            this.presenter = presenter;
            this.presenter.Refreshed += (sender, e) => this.RefreshData();
            this.presenter.TypeCreated += (sender, e) => this.CreateType(e.Data);
            this.presenter.TypeRemoved += (sender, e) => this.RemoveType(e.Data);
            this.presenter.TypeUpdated += (sender, e) => this.UpdateType(e.Data);
            this.presenter.Updated += (sender, e) => this.UpdatePatient();
        }

        #endregion Constructors

        #region Methods

        private void CreateType(MedicalCardType toAdd)
        {
            this.mcTypeRepository.Create(toAdd);
            this.RefreshData();
        }

        private void RefreshData()
        {
            this.presenter.MedicalCardTypes = (from type in this.mcTypeRepository.GetAllRows()
                                               orderby type.Title ascending
                                               select type).ToList();

            this.presenter.Macros = this.macroRepository.GetAllRows();
        }

        private void RemoveType(MedicalCardType toRemove)
        {
            this.mcTypeRepository.Delete(toRemove);
            this.RefreshData();
        }

        private void UpdatePatient()
        {
            this.patientRepository.Update(this.presenter.Patient);
            this.RefreshData();
        }

        private void UpdateType(MedicalCardType toUpdate)
        {
            this.mcTypeRepository.Update(toUpdate);
            this.RefreshData();
        }

        #endregion Methods
    }
}