﻿namespace Phoenix.Model.Management
{
    using System;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Presenter;
    using Phoenix.Presenter.Interfaces.Input;
    using Phoenix.Translation;

    /// <summary>
    /// Provides features to manage the reputation.
    /// </summary>
    public class ReputationModel : Manager<Reputation>
    {
        #region Fields

        private IReputationInputPresenter presenter;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="ReputationModel"/> class.
        /// </summary>
        /// <param name="presenter">The presenter.</param>
        public ReputationModel(IReputationInputPresenter presenter)
            : base(RepositoryFactory.Get<IReputationRepository>())
        {
            this.presenter = presenter;
            this.presenter.Inserted += view_Inserted;
            this.presenter.Updated += view_Updated;
            this.presenter.Deleted += view_Deleted;
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Validates the data.
        /// </summary>
        /// <returns><c>True</c> if the data have passed the validation;
        /// otherwise <c>False</c></returns>
        public override bool ValidateData()
        {
            bool result = true;
            string text = this.presenter.ItemToManage.Title;
            if (string.IsNullOrEmpty(text))
            {
                this.presenter.SetError(ReputationFailedOn.EmptyTitle, "A reputation can't be without name.".Translate());
                result = false;
            }
            return result;
        }

        private void view_Deleted(object sender, EventArgs e)
        {
            if (this.Repository.IsReferenced(this.presenter.ItemToManage))
            {
                this.presenter.SetError(ReputationFailedOn.Referenced, "Impossible to delete this item, it is referenced somewhere else.");
            }
            else
            {
                this.Delete(this.presenter.ItemToManage);
            }
        }

        private void view_Inserted(object sender, EventArgs e)
        {
            this.Insert(this.presenter.ItemToManage);
        }

        /// <summary>
        /// Handles the Updated event of the view control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        private void view_Updated(object sender, EventArgs e)
        {
            this.Update(this.presenter.ItemToManage);
        }

        #endregion Methods
    }
}