﻿namespace Phoenix.Model.Search
{
    using System.Collections.Generic;

    using Phoenix.Contracts;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Presenter.Interfaces.Interfaces;
    using Phoenix.Presenter.Interfaces.Searcher;

    /// <summary>
    /// Presenter for search box for drugs
    /// </summary>
    public class DrugSearcher : Searcher<Drug>
    {
        #region Fields

        private IDrugSearchBox presenter;
        private IDrugRepository repository = RepositoryFactory.Get<IDrugRepository>();
        private IDrugTypeRepository typeRepository = RepositoryFactory.Get<IDrugTypeRepository>();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="DrugSearcher"/> class.
        /// </summary>
        /// <param name="view">The view.</param>
        public DrugSearcher(IDrugSearchBox view)
            : base(view)
        {
            this.presenter = view;
            this.presenter.Loading += (sender, e) => this.SetDrugTypes();
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Deletes the specified item from the repository.
        /// </summary>
        /// <param name="item">The item.</param>
        public override void Delete(Drug item)
        {
            Assert.IsNotNull(item, "item");
            RepositoryFactory.Get<IDrugRepository>().Delete(item);
        }

        /// <summary>
        /// Start a search on a user demand.
        /// </summary>
        /// <param name="criterion">The criterion.</param>
        /// <returns></returns>
        public override IList<Drug> ProcessSearch(object criterion)
        {
            Assert.IsType(criterion, typeof(Drug));

            var title = (criterion as Drug).Title;
            var type = (criterion as Drug).Type;

            if (!string.IsNullOrEmpty(title) && type != null) return repository.Search(title, type);
            if (!string.IsNullOrEmpty(title) && type == null) return repository.Search(title);
            if (string.IsNullOrEmpty(title) && type != null) return repository.Search(type);
            else return new List<Drug>();
        }

        private IList<Drug> AllItems()
        {
            return repository.GetAllRows();
        }

        private IList<Drug> RegularSearch(object criterion)
        {
            string drug = criterion as string;
            Assert.IsTrue(drug != null, "The criterion should be a 'string'");

            IList<Drug> result = repository.Search(drug);

            if (result.Count == 0)
                this.View.WarnOnZeroResult();
            return result;
        }

        private void SetDrugTypes()
        {
            var types = this.typeRepository.GetAllRows(OrderBy.ASC);
            this.presenter.SetDrugTypes(types.ToArray());
        }

        #endregion Methods
    }
}