﻿namespace Phoenix.Model.Search
{
    using System;
    using System.Collections.Generic;

    using Phoenix.Contracts;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Presenter.Interfaces.Interfaces;

    /// <summary>
    /// Presenter for search in prescriptions
    /// </summary>
    public class PrescriptionSearcher : Searcher<Prescription>
    {
        #region Fields

        private IPrescriptionRepository repository = RepositoryFactory.Get<IPrescriptionRepository>();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="PrescriptionSearcher"/> class.
        /// </summary>
        /// <param name="view">The view.</param>
        public PrescriptionSearcher(ISearchBox<Prescription> view)
            : base(view)
        {
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Deletes the specified item from the repository.
        /// </summary>
        /// <param name="item">The item.</param>
        public override void Delete(Prescription item)
        {
            Assert.IsNotNull(item, "item");
            this.repository.Delete(item);
        }

        /// <summary>
        /// Start a search on a user demand.
        /// </summary>
        /// <param name="criterion">The criterion.</param>
        /// <returns></returns>
        public override IList<Prescription> ProcessSearch(object criterion)
        {
            Assert.IsType(criterion, typeof(Criterion));
            Criterion value = criterion as Criterion;

            return this.repository.Search(value.Patient, value.FromDate, value.ToDate);
        }

        #endregion Methods

        #region Nested Types

        /// <summary>
        /// Criterion to process a search
        /// </summary>
        public class Criterion
        {
            #region Properties

            /// <summary>
            /// Gets or sets starting date of the search's range.
            /// </summary>
            /// <value>From date.</value>
            public DateTime FromDate
            {
                get;
                set;
            }

            /// <summary>
            /// Gets or sets the patient involved in the search.
            /// </summary>
            /// <value>The patient.</value>
            public Patient Patient
            {
                get;
                set;
            }

            /// <summary>
            /// Gets or sets ending date of the search's range.
            /// </summary>
            /// <value>To date.</value>
            public DateTime ToDate
            {
                get;
                set;
            }

            #endregion Properties
        }

        #endregion Nested Types
    }
}