namespace Phoenix.Presenter.Interfaces
{
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Presenter.Sessions;

    /// <summary>
    /// A session GUI is a manager that manage all the GUI managers used in a session.
    /// </summary>
    public interface ISessionGui
    {
        #region Properties

        /// <summary>
        /// Gets or sets the patient manager. That's, the gui item
        /// related to the management of the patient the user
        /// opened for this session.
        /// </summary>
        /// <value>The patient manager.</value>
        ISimpleInsertBox<Patient> PatientManager
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the session the SessionGui manages.
        /// </summary>
        /// <value>The session.</value>
        Session Session
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Closes the session and dispose all the GUI item related
        /// to the current session.
        /// </summary>
        void Close();

        /// <summary>
        /// Saves all the value of the session into the repository.
        /// </summary>
        void Save();

        #endregion Methods
    }
}