﻿namespace Phoenix.Presenter.Interfaces.Input
{
    using System.Collections.Generic;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Presenter.Helpers;

    #region Enumerations

    /// <summary>
    /// Indicates the source of the validation failure
    /// </summary>
    public enum RelationFailedOn
    {
        /// <summary>
        /// The relation does not have a parent
        /// </summary>
        NoParent,
        /// <summary>
        /// The relation does not have any type.
        /// </summary>
        NoRelationType,
    }

    #endregion Enumerations

    /// <summary>
    /// Provide a Gui to manage the relations of a patient
    /// </summary>
    public interface IRelationInputPresenter
    {
        #region Properties

        /// <summary>
        /// Gets or sets the managed Patient.
        /// </summary>
        /// <value>The item to manage.</value>
        Patient Patient
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the relations.
        /// </summary>
        /// <value>The relations.</value>
        List<RelationType> Relations
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the selected relation.
        /// </summary>
        /// <value>The selected relation.</value>
        Relation SelectedRelation
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the usage of this GUI item.
        /// </summary>
        /// <value>The usage.</value>
        Usage Usage
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Clears the error.
        /// </summary>
        void ClearError();

        /// <summary>
        /// Sets the error.
        /// </summary>
        /// <param name="failure">The failure.</param>
        /// <param name="message">The message.</param>
        void SetError(RelationFailedOn failure, string message);

        #endregion Methods
    }
}