﻿namespace Phoenix.Presenter.Interfaces.Manager
{
    using System;
    using System.Collections.Generic;

    using Phoenix.Helpers.Misc;
    using Phoenix.Model.Bll.Domain;

    #region Enumerations

    /// <summary>
    /// Indicates where the specified relation is not valid
    /// </summary>
    public enum FamilyFailedOn
    {
        /// <summary>
        /// The two ends of the relation is the same person
        /// </summary>
        RecursiveRelation,
    }

    #endregion Enumerations

    /// <summary>
    /// Provides feature for a GUI to manage family
    /// </summary>
    public interface IFamilyManagerPresenter : IManager
    {
        #region Events

        /// <summary>
        /// Occurs when a patient is loading.
        /// </summary>
        event EventHandler<EventArgs<Patient>> PatientLoading;

        /// <summary>
        /// Occurs when the view is refreshed.
        /// </summary>
        event EventHandler Refreshed;

        /// <summary>
        /// Occurs when a relation is deleted.
        /// </summary>
        event EventHandler<EventArgs<Relation>> RelationDeleted;

        /// <summary>
        /// Occurs when a relation is inserted.
        /// </summary>
        event EventHandler<EventArgs<Relation>> RelationInserted;

        /// <summary>
        /// Occurs when a relation is updated.
        /// </summary>
        event EventHandler<EventArgs<Relation>> RelationUpdated;

        #endregion Events

        #region Properties

        /// <summary>
        /// Gets or sets the relation types.
        /// </summary>
        /// <value>The relation types.</value>
        List<RelationType> RelationTypes
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Sets an error message to explain why data validation failed.
        /// </summary>
        /// <param name="failed">The fail.</param>
        /// <param name="message">The error message.</param>
        void SetError(FamilyFailedOn failure, string errorMessage);

        #endregion Methods
    }
}