﻿namespace Phoenix.Test.MedicalCardRelease
{
    using System;
    using System.Collections.Generic;
    using System.Diagnostics;
    using System.Drawing;

    using NUnit.Framework;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Model.Dal.Helpers;
    using Phoenix.Model.Dal.Repositories;

    /// <summary>
    /// Do not use this test suite as UnitTest!
    /// </summary>
    /// <remarks>
    /// This assembly is build in x86 and not in adm64 then you have to select
    /// the nUnit x86 Gui to make them runnable.
    /// </remarks>   
    //[TestFixture]
    public class FunctionalTestSuite
    {
        #region Fields

        private IKeywordGroupRepository groupRepository;

        #endregion Fields

        #region Methods

        public void LoadKeyword()
        {
            IList<KeywordGroup> groups = groupRepository.GetAllRows();
            Debug.WriteLine("Group count: " + groups.Count);
        }

        [SetUp]
        public void Setup()
        {
            OrmManager.Initialize();
            groupRepository = RepositoryFactory.Get<IKeywordGroupRepository>();
        }

        public void TestDALForKeywordGroups()
        {
            groupRepository.RemoveAll();

            KeywordGroup group = new KeywordGroup()
            {
                Color = Color.FromArgb(10, 150, 42),
                Title = "One",
            };
            groupRepository.Create(group);

            group = new KeywordGroup()
            {
                Color = Color.Beige,
                Title = "Two",
            };
            groupRepository.Create(group);

            group = new KeywordGroup()
            {
                Color = Color.Blue,
                Title = "Three",
            };
            groupRepository.Create(group);

            group = new KeywordGroup()
            {
                Color = Color.Yellow,
                Title = "Four",
            };
            groupRepository.Create(group);

            List<KeywordGroup> list = groupRepository.GetAllRows();

            Assert.IsTrue(list.Count == 4, string.Format(
                "There are more item than expected (count: {0}", list.Count));
        }

        //[Test]
        public void TestDALForKeywords()
        {
            groupRepository.RemoveAll();

            KeywordGroup group = new KeywordGroup()
            {
                Color = Color.Red,
                Title = "Test group"
            };
            group.Keywords.Add("Keyword");
            group.Keywords.Add("KeywordTwo");

            groupRepository.CreateOrUpdate(group);
        }

        //[Test]
        public void TestDALForMacro()
        {
            Macro macro = new Macro();
            Patient patient = new Patient();
            patient.FirstName = "Jean-Baptiste";
            patient.LastName = "Wautier";
            patient.DateOfBirth = new System.DateTime(1978, 06, 02);

            macro.Text = string.Format("Bonjour {0}. Tu as {1} ans puisque tu es né le {2}. On est le {3} et il est {4}"
                , Macro.GetTag(Macro.Predifined.PatientName)
                , Macro.GetTag(Macro.Predifined.PatientAge)
                , Macro.GetTag(Macro.Predifined.BirthDate)
                , Macro.GetTag(Macro.Predifined.Today)
                , Macro.GetTag(Macro.Predifined.Now));

            macro.Bind(patient);
            Debug.WriteLine(macro.Text);
        }

        //[Test]
        public void TestDalForMedicalCard()
        {
            IMedicalCardRepository medRepository = new MedicalCardRepository();
            IPatientRepository patRepository = new PatientRepository();

            MedicalCardType type = new MedicalCardType();
            type.Title = "Some type";
            type.Remark = "Some remarks";

            MedicalCardType type2 = new MedicalCardType();
            type2.Title = "Some type 2";
            type2.Remark = "Some remarks";

            MedicalCard mc = new MedicalCard();
            mc.Remark = "one";
            mc.Title = "one";
            mc.Type = type;
            mc.UpdateDate = new DateTime(2010, 10, 10);

            MedicalCard mc2 = new MedicalCard();
            mc2.Remark = "two";
            mc2.Title = "two";
            mc2.Type = type2;
            mc2.UpdateDate = new DateTime(2010, 10, 10);

            Patient patient = new Patient();
            patient.FirstName = "Robert";
            patient.LastName = "Dupont";
            patient.Add(mc);
            patient.Add(mc2);

            //medRepository.Create(mc);
            //medRepository.Create(mc2);
            patRepository.Create(patient);

            int count = 2;
            List<MedicalCard> result = medRepository.GetAllRows();
            Assert.AreEqual(count, result.Count, string.Format(
                "The repository should have {0} medial cards but it has got {1}", count, result.Count));

            int cardCount = 1;
            List<MedicalCard> medCards = patient.GetMedicalCardsOfType(type);
            Assert.AreEqual(cardCount, medCards.Count, string.Format(
                "The repository should have found {0} medical cards but has got {1} items", cardCount, medCards.Count));
        }

        #endregion Methods
    }
}