﻿namespace Phoenix.View.Input
{
    using System;
    using System.Collections.Generic;
    using System.Windows.Forms;

    using Phoenix.Helpers.Misc;

    /// <summary>
    /// Input from a ComboBox
    /// </summary>
    public partial class ComboBoxInput : Form
    {
        #region Fields

        private object dataSource;
        private string displayMember;
        private bool isEnum;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="ComboBoxInput"/> class.
        /// </summary>
        /// <param name="dataSource">The data source.</param>
        /// <param name="displayMember">The display member.</param>
        public ComboBoxInput(object dataSource, string displayMember)
        {
            InitializeComponent();
            this.dataSource = dataSource;
            this.displayMember = displayMember;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ComboBoxInput"/> class.
        /// </summary>
        /// <param name="dataSource">The data source.</param>        
        public ComboBoxInput(object dataSource)
        {
            InitializeComponent();
            this.dataSource = dataSource;
            this.displayMember = null;
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets the selected item.
        /// </summary>
        /// <value>The selected item.</value>
        public object SelectedItem
        {
            get
            {
                if (this.isEnum) return this.cb_Combo.SelectedValue;
                else return this.cb_Combo.SelectedItem;
            }
        }

        #endregion Properties

        #region Methods

        private void btn_OK_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.OK;
            this.Close();
        }

        private void ComboBoxInput_Load(object sender, EventArgs e)
        {
            if (this.dataSource.GetType().IsEnum) this.SetDataSourceForEnum();
            else this.SetDataSourceForObject();
        }

        private void SetDataSourceForEnum()
        {
            this.isEnum = true;
            var list = new List<KeyValuePair<string, object>>();

            foreach (Enum each in Enum.GetValues(this.dataSource.GetType()))
            {
                var kvalue = new KeyValuePair<string, object>(
                         EnumHelper.GetDescription(each)
                         , each);
                list.Add(kvalue);
            }

            this.cb_Combo.DataSource = list;
            this.cb_Combo.DisplayMember = "Key";
            this.cb_Combo.ValueMember = "Value";
        }

        private void SetDataSourceForObject()
        {
            this.isEnum = false;
            this.cb_Combo.DataSource = this.dataSource;
            if (!string.IsNullOrEmpty(this.displayMember))
                this.cb_Combo.DisplayMember = this.displayMember;
        }

        #endregion Methods
    }
}