﻿namespace Phoenix.Presenter.Management.Controls
{
    using System.Windows.Forms;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Translation;

    /// <summary>
    /// Provide a control to get an address typed by the user.
    /// </summary>
    public partial class AddressControl : UserControl
    {
        #region Fields

        private Address address = new Address();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="AddressControl"/> class.
        /// </summary>
        public AddressControl()
        {
            InitializeComponent();
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets the address contained into the component.
        /// </summary>
        /// <value>The address.</value>
        public Address Address
        {
            get
            {
                Address localAddress = this.address;
                localAddress.BoxNumber = this.tb_BoxNumber.Text;
                localAddress.City = this.tb_City.Text;
                localAddress.PostalCode = this.tb_PostalCode.Text;
                localAddress.Street = this.tb_Street.Text;
                localAddress.StreetNumber = this.tb_StreetNumber.Text;
                return localAddress;
            }
            set
            {
                if (value != null)
                {
                    this.address = value;
                    this.tb_BoxNumber.Text = value.BoxNumber;
                    this.tb_City.Text = value.City;
                    this.tb_PostalCode.Text = value.PostalCode;
                    this.tb_Street.Text = value.Street;
                    this.tb_StreetNumber.Text = value.StreetNumber;
                }
            }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Clears the error.
        /// </summary>
        public void ClearError()
        {
            this.ep_Error.Clear();
        }

        /// <summary>
        /// Invalidates the city indicating an error message.
        /// </summary>
        /// <param name="msg">The MSG.</param>
        public void InvalidateCity(string msg)
        {
            this.ep_Error.SetError(tb_City, msg);
        }

        /// <summary>
        /// Invalidates the street indicating an error message.
        /// </summary>
        /// <param name="msg">The MSG.</param>
        public void InvalidateStreet(string msg)
        {
            this.ep_Error.SetError(tb_Street, msg);
        }

        /// <summary>
        /// Checks the validity of the entered values.
        /// </summary>
        /// <returns><c>True</c> if all values are valid. Otherwise <c>False</c>.</returns>
        public bool ValidateData()
        {
            this.ep_Error.Clear();
            bool result = true;
            string msg;

            if (string.IsNullOrEmpty(this.tb_StreetNumber.Text))
            {
                msg = string.Format("The street number can't be empty!".Translate());
                this.ep_Error.SetError(tb_StreetNumber, msg);
                result = false;
            }
            if (string.IsNullOrEmpty(this.tb_Street.Text))
            {
                msg = string.Format("The street can't be empty!".Translate());
                this.ep_Error.SetError(tb_Street, msg);
                result = false;
            }
            if (string.IsNullOrEmpty(this.tb_PostalCode.Text))
            {
                msg = string.Format("The postal code can't be empty!".Translate());
                this.ep_Error.SetError(tb_PostalCode, msg);
                result = false;
            }
            if (string.IsNullOrEmpty(this.tb_City.Text))
            {
                msg = string.Format("The city can't be empty!".Translate());
                this.ep_Error.SetError(tb_City, msg);
                result = false;
            }
            return result;
        }

        #endregion Methods
    }
}