﻿namespace Phoenix.Presenter.Management.Controls
{
    using System.Windows.Forms;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Presenter.Helpers;

    /// <summary>
    /// Control that provides possibility to manage an insurance.
    /// </summary>
    public partial class PracticeManagerControl : UserControl
    {
        #region Fields

        private Practice practice = new Practice();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="PracticeManagerControl"/> class.
        /// </summary>
        public PracticeManagerControl()
        {
            InitializeComponent();
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the practice.
        /// </summary>
        /// <value>The practice.</value>
        public Practice ItemToManage
        {
            get
            {
                this.practice.Address = this.ac_Address.Address;
                this.practice.Phone = this.tb_Phone.Text;
                this.practice.Title = this.tb_Name.Text;
                return practice;
            }
            set
            {
                this.practice = value;
                this.ac_Address.Address = value.Address;
                this.tb_Name.Text = value.Title;
                this.tb_Phone.Text = value.Phone;
            }
        }

        /// <summary>
        /// Gets the action that control execute.
        /// </summary>
        /// <value>The action.</value>
        public Usage Usage
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Sets an error message on empty name for the 
        /// practice.
        /// </summary>
        /// <param name="msg">The MSG.</param>
        public void SetEmptyNameError(string msg)
        {
            this.ep_Error.SetError(this.tb_Name, msg);
        }

        #endregion Methods
    }
}