﻿namespace Phoenix.Presenter.Search.Criterion
{
    using System.ComponentModel;
    using System.Text.RegularExpressions;
    using System.Windows.Forms;

    /// <summary>
    /// Provides an input for mail criterion.
    /// </summary>
    public class MailCriterion : CriterionControl, ICriterionControl
    {
        #region Fields

        private TextBox tb_TextBox = new TextBox();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="MailCriterion"/> class.
        /// </summary>
        public MailCriterion()
            : base()
        {
            base.AddInCriterionControl(tb_TextBox);
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets the criterion's number.
        /// </summary>
        /// <value></value>
        /// <number>The criterion's number.</number>
        [Browsable(false)]
        public override object Value
        {
            get
            {
                return this.tb_TextBox.Text;
            }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Checks the values the user entered and provides
        /// warning message if values are not correct.
        /// </summary>
        public override bool ValidateCriterions()
        {
            if (base.IsActivated)
            {
                Regex regex = new Regex(@"^(([A-Za-z0-9]+_+)|([A-Za-z0-9]+\-+)|([A-Za-z0-9]+\.+)|([A-Za-z0-9]+\++))*[A-Za-z0-9]+@((\w+\-+)|(\w+\.))*\w{1,63}\.[a-zA-Z]{2,6}$");
                MatchCollection matches = regex.Matches(this.tb_TextBox.Text);

                if (matches.Count == 0)
                {
                    string msg = "The mail does not respect the pattern. A mail should ressemble to 'name@mail.com'";
                    base.SetError(msg);
                    return false;
                }
                else
                {
                    return true;
                }
            }
            else
            {
                return true;
            }
        }

        /// <summary>
        /// Clears the value of the criterion.
        /// </summary>
        protected override void ClearValue()
        {
            this.tb_TextBox.Text = string.Empty;
        }

        #endregion Methods
    }
}