﻿namespace Phoenix.Presenter.Search.Criterion
{
    using System.ComponentModel;
    using System.Windows.Forms;

    using Phoenix.Translation;

    /// <summary>
    /// Provides an input for view criterion.
    /// </summary>
    public partial class TextCriterion : CriterionControl, ICriterionControl
    {
        #region Fields

        TextBox tb_TextBox = new TextBox();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="TextCriterion"/> class.
        /// </summary>
        public TextCriterion()
            : base()
        {
            base.AddInCriterionControl(tb_TextBox);
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets a value indicating whether this instance is control.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is control; otherwise, <c>false</c>.
        /// </value>
        public override bool IsControl
        {
            get { return ((this as Control) != null); }
        }

        /// <summary>
        /// Gets the criterion's number.
        /// </summary>
        /// <value></value>
        /// <number>The criterion's number.</number>
        [Browsable(false)]
        public override object Value
        {
            get
            {
                return this.tb_TextBox.Text;
            }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Checks the values the user entered and provides
        /// warning message if values are not correct.
        /// </summary>
        public override bool ValidateCriterions()
        {
            if (base.IsActivated)
            {
                float number;
                if (float.TryParse(this.tb_TextBox.Text, out number))
                {
                    string msg = "You entered a number ('{0}') while text is expected!".Translate(number.ToString());
                    base.SetError(msg);
                    return false;
                }
                else if (string.IsNullOrEmpty(this.tb_TextBox.Text))
                {
                    string msg = ("If you don't want to use this criterium, please deactivate it by unchecking it. "
                        + "Otherwise add some text.").Translate();
                    base.SetError(msg);
                    return false;
                }
                else
                {
                    base.ClearError();
                    return true;
                }
            }
            else
            {
                return true;
            }
        }

        /// <summary>
        /// Clears the value of the criterion.
        /// </summary>
        protected override void ClearValue()
        {
            this.tb_TextBox.Text = string.Empty;
        }

        #endregion Methods
    }
}