﻿namespace Phoenix.Helpers.Xml
{
    using System.Xml;

    /// <summary>
    /// Provides helpers methods to access a XML file
    /// </summary>
    public static class XmlAccessor
    {
        #region Delegates

        private delegate string NodeProcess(XmlNode node);

        #endregion Delegates

        #region Methods

        /// <summary>
        /// Gets the element with specified key from the specified config file.
        /// Returns null if, for whatever reason, value is impossible to find.
        /// </summary>
        /// <param name="fullPath">The full path.</param>
        /// <param name="key">The key.</param>
        /// <param name="xpath">The xpath of the key to access.</param>
        /// <returns>
        /// The value of the specified key or null if not found.
        /// </returns>
        public static string GetElement(string fullPath, string key, string xpath)
        {
            return Get(fullPath, xpath, new NodeProcess(delegate(XmlNode node)
            {
                if (node.Name == key)
                {
                    return node.InnerText;
                }
                return null;
            }));
        }

        /// <summary>
        /// Gets the specified key from the specified config file.
        /// Returns null if, for whatever reason, value is impossible to find.
        /// For default config file use this xpath = "configuration/appSettings/add"
        /// </summary>
        /// <param name="fullPath">The full path.</param>
        /// <param name="key">The key.</param>
        /// <param name="xpath">The xpath of the key to access.</param>
        /// <returns>
        /// The value of the specified key or null if not found.
        /// </returns>
        public static string GetKey(string fullPath, string key, string xpath)
        {
            return Get(fullPath, xpath, new NodeProcess(delegate(XmlNode node)
            {
                if (node.Attributes["key"].Value == key)
                {
                    return node.Attributes["value"].Value;
                }
                return null;
            }));
        }

        private static string Get(string fullPath, string xpath, NodeProcess action)
        {
            XmlDocument document = new XmlDocument();
            document.Load(fullPath);
            XmlNodeList nodeList = document.SelectNodes(xpath);
            foreach (XmlNode node in nodeList)
            {
                string result = action(node);
                if (result != null)
                    return result;
            }
            return null;
        }

        #endregion Methods
    }
}